summaryrefslogtreecommitdiff
path: root/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx')
-rw-r--r--sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx b/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx
index af5bd5791ba4..4de3e6a1c095 100644
--- a/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx
+++ b/sd/source/ui/slidesorter/shell/SlideSorterViewShell.cxx
@@ -74,7 +74,7 @@ namespace sd::slidesorter {
namespace {
-bool inChartContext(const sd::View* pView)
+bool inChartOrMathContext(const sd::View* pView)
{
if (!pView)
return false;
@@ -82,7 +82,7 @@ bool inChartContext(const sd::View* pView)
SfxViewShell* pViewShell = pView->GetSfxViewShell();
SidebarController* pSidebar = SidebarController::GetSidebarControllerForView(pViewShell);
if (pSidebar)
- return pSidebar->hasChartContextCurrently();
+ return pSidebar->hasChartOrMathContextCurrently();
return false;
}
@@ -459,9 +459,9 @@ void SlideSorterViewShell::ArrangeGUIElements()
void SlideSorterViewShell::Activate (bool bIsMDIActivate)
{
- if(inChartContext(GetView()))
+ if(inChartOrMathContext(GetView()))
{
// Avoid context changes for chart during activation / deactivation.
const bool bIsContextBroadcasterEnabled (SfxShell::SetContextBroadcasterEnabled(false));
ViewShell::Activate(bIsMDIActivate);
@@ -459,9 +459,9 @@ void SlideSorterViewShell::ArrangeGUIElements()
{
- // Avoid context changes for chart during activation / deactivation.
+ // Avoid context changes for chart/math during activation / deactivation.
const bool bIsContextBroadcasterEnabled (SfxShell::SetContextBroadcasterEnabled(false));
ViewShell::Activate(bIsMDIActivate);